function MatlabCallback(obj,event)
% MatlabCallback - Callback called by a MatlabServer object for
% implementing a proxy
% 
% CALL:
%     MatlabCallback(obj, event)
% 
% INPUT:
%     obj: 
%         handle to the MatlabServer object which triggered the callback
%     event: 
%         ServerEvent with query and response information
% 
% OUTPUT:
%     No output
%
% EXAMPLE:
%     addpath('###\matlabserver\matlabcode')           %for startMatlabServer
%     addpath('###\matlabserver\matlabcode\examples\') %for MatlabCallback&remote_eval
%     server = startMatlabServer(4444, @MatlabCallback);
%     First verification:
%     open in browser: http://localhost:8080/matlabserver/myExample
%     Final verification:
%     <open a 2nd Matlab sesion>
%     remote_eval %No arguments required, run default example
%
% See also: remote_eval
    
%   Copyright 2006-2021 Modelit, www.modelit.nl

try 
    % Get the request string
    str = getInputString(event);
    
    % Deserialize the request string
    %REVISION ZIJPP 20150825: replace deserialize with deserialize_v2
    %Note: remote_eval uses "urlencode_utf", so apply "urldecode_utf"
    %before using str.
    input=deserialize_v2(str);
    
    % Generate the response. 
    % Note: input{1} is function to apply
    %       inpute{2:end} are arguments to apply
    output=feval(input{1},input{2:end});
            
    % Return response to the client
    %REVISION ZIJPP 20150825: replace serialize with serialize_v2
    %Note: No encodeing needed for reply.
    sendResponse(event, serialize_v2(output));
catch 
    %In case of error, serialize error data
    sendResponse(event, serialize_v2(lasterror));
end