function value=remote_eval(url,fp,varargin)
% remote_eval - function that should be used on the client computer for
% remote execution of sepcified function
% 
% INPUT:
%     url:
%         location of webservice. If empty, use example directory on
%         localhost 
%     fp:
%         function pointer for function to execute
%     varargin
%         arguments for function
% 
% OUTPUT:
%     value: 
%         result of function. Type depends on function.
%
% EXAMPLE:
%     addpath('###\matlabserver\matlabcode')           %for startMatlabServer
%     addpath('###\matlabserver\matlabcode\examples\') %for MatlabCallback&remote_eval
%     
%     server = startMatlabServer(4444, @MatlabCallback);
%     First verification:
%     open in browser: http://localhost:8080/matlabserver/myExample
%     Final verification:
%     <open a 2nd Matlab sesion>
%     remote_eval %No arguments required, run default example
%
% See also: remote_eval
%   Copyright 2006-2021 Modelit, www.modelit.nl
%

if nargin==0
    %When called with no arguments: test this function.
    
    %Note that callback must be active in remote Matlab thread. Beware if
    %testing this example on localhost. Execute next line in SECOND Matlab
    %session.  server=startMatlabServer(4444,@MatlabCallback)
    
    %Use utility "remote_eval" to test
    %example 1 (default example)
    value=remote_eval('',@max,[999,99,9],[9,99,999])
    return
    %example 2 (catch error)
    value=remote_eval('',@max,[999,99,9],[9,99,999,9999])
    %example 3 (>10^6 bytes data transfer)
    value=remote_eval('',@rand,1000);
end

if isempty(url)
    url='http://localhost:8080/matlabserver/myExample?';
end

%Apply convention:
%- function and input data are stored in cell array
%- first element of cell array is pointer to function
%- next elements are input data
cmd_array=cat(2,{fp},varargin{:});

%serialize to byte string
%REVISION ZIJPP 20150825: replace serialize with serialize_v2
cmdstr=serialize_v2(cmd_array);

%call remote counter part
%REVISION ZIJPP 20211223: replace urlread with webwrite (ovveride default
%timeout of 5 seconds)
str=webwrite(url,cmdstr(:)',weboptions('Timeout',inf));

%Note that webwrite requires Matlab R2015a or beyond. For earlier versions
%consider urlread (but note that urldecode_utf must be applied at the
%receiving end too): 
% str=urlread([url,urlencode_utf(cmdstr(:)')]);

%deserialize result
%REVISION ZIJPP 20150825: replace deserialize with deserialize_v2
value=deserialize_v2(str);

%verify that result does not originate from catch part
if isstruct(value)&&isfield(value,'identifier')
    rethrow(value);
end


    